/********************************************************************************
** Form generated from reading UI file 'wmselectdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WMSELECTDIALOG_H
#define UI_WMSELECTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_WmSelectDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTreeWidget *wmList;
    QLabel *label_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *WmSelectDialog)
    {
        if (WmSelectDialog->objectName().isEmpty())
            WmSelectDialog->setObjectName("WmSelectDialog");
        WmSelectDialog->resize(600, 400);
        verticalLayout = new QVBoxLayout(WmSelectDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(WmSelectDialog);
        label->setObjectName("label");
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        wmList = new QTreeWidget(WmSelectDialog);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(1, QString::fromUtf8("2"));
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        wmList->setHeaderItem(__qtreewidgetitem);
        wmList->setObjectName("wmList");
        QFont font;
        font.setBold(false);
        wmList->setFont(font);
        wmList->setEditTriggers(QAbstractItemView::NoEditTriggers);
        wmList->setAlternatingRowColors(true);
        wmList->setRootIsDecorated(false);
        wmList->setUniformRowHeights(true);
        wmList->setAllColumnsShowFocus(true);
        wmList->setColumnCount(2);
        wmList->header()->setVisible(false);

        verticalLayout->addWidget(wmList);

        label_2 = new QLabel(WmSelectDialog);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout->addWidget(label_2);

        buttonBox = new QDialogButtonBox(WmSelectDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(WmSelectDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, WmSelectDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, WmSelectDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(WmSelectDialog);
    } // setupUi

    void retranslateUi(QDialog *WmSelectDialog)
    {
        WmSelectDialog->setWindowTitle(QCoreApplication::translate("WmSelectDialog", "Welcome to LXQt", nullptr));
        label->setText(QCoreApplication::translate("WmSelectDialog", "<html><head/><body><p><span style=\" font-weight:600;\">Welcome to LXQt</span></p><p>Please select your default Window Manager:</p></body></html>", nullptr));
        label_2->setText(QCoreApplication::translate("WmSelectDialog", "<html><head/><body><p>You will be able to change this at any time through <span style=\"font-weight:600;\">LXQt Settings \342\206\222 Session Settings \342\206\222 X11 Settings</span>.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WmSelectDialog: public Ui_WmSelectDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WMSELECTDIALOG_H
