/********************************************************************************
** Form generated from reading UI file 'autostartpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOSTARTPAGE_H
#define UI_AUTOSTARTPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AutoStartPage
{
public:
    QGridLayout *gridLayout_10;
    QLabel *label;
    QTreeView *autoStartView;
    QPushButton *addButton;
    QPushButton *editButton;
    QPushButton *deleteButton;
    QSpacerItem *verticalSpacer_1;

    void setupUi(QWidget *AutoStartPage)
    {
        if (AutoStartPage->objectName().isEmpty())
            AutoStartPage->setObjectName("AutoStartPage");
        AutoStartPage->resize(320, 240);
        gridLayout_10 = new QGridLayout(AutoStartPage);
        gridLayout_10->setObjectName("gridLayout_10");
        label = new QLabel(AutoStartPage);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        gridLayout_10->addWidget(label, 0, 0, 1, 1);

        autoStartView = new QTreeView(AutoStartPage);
        autoStartView->setObjectName("autoStartView");
        autoStartView->header()->setVisible(false);

        gridLayout_10->addWidget(autoStartView, 1, 0, 5, 1);

        addButton = new QPushButton(AutoStartPage);
        addButton->setObjectName("addButton");

        gridLayout_10->addWidget(addButton, 2, 1, 1, 1);

        editButton = new QPushButton(AutoStartPage);
        editButton->setObjectName("editButton");

        gridLayout_10->addWidget(editButton, 3, 1, 1, 1);

        deleteButton = new QPushButton(AutoStartPage);
        deleteButton->setObjectName("deleteButton");

        gridLayout_10->addWidget(deleteButton, 4, 1, 1, 1);

        verticalSpacer_1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_10->addItem(verticalSpacer_1, 5, 1, 1, 1);


        retranslateUi(AutoStartPage);

        QMetaObject::connectSlotsByName(AutoStartPage);
    } // setupUi

    void retranslateUi(QWidget *AutoStartPage)
    {
        label->setText(QCoreApplication::translate("AutoStartPage", "Application Autostart", nullptr));
        addButton->setText(QCoreApplication::translate("AutoStartPage", "Add", nullptr));
        editButton->setText(QCoreApplication::translate("AutoStartPage", "Edit", nullptr));
        deleteButton->setText(QCoreApplication::translate("AutoStartPage", "Delete", nullptr));
        (void)AutoStartPage;
    } // retranslateUi

};

namespace Ui {
    class AutoStartPage: public Ui_AutoStartPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUTOSTARTPAGE_H
