/********************************************************************************
** Form generated from reading UI file 'waylandsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WAYLANDSETTINGS_H
#define UI_WAYLANDSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_WaylandSettings
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout;
    QComboBox *compositorComboBox;
    QPushButton *findCompositorButton;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_1;
    QComboBox *wayLockCommandComboBox;
    QPushButton *findWayLockCommandButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *WaylandSettings)
    {
        if (WaylandSettings->objectName().isEmpty())
            WaylandSettings->setObjectName("WaylandSettings");
        WaylandSettings->resize(300, 300);
        verticalLayout = new QVBoxLayout(WaylandSettings);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(WaylandSettings);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        verticalLayout->addWidget(label);

        groupBox = new QGroupBox(WaylandSettings);
        groupBox->setObjectName("groupBox");
        horizontalLayout = new QHBoxLayout(groupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        compositorComboBox = new QComboBox(groupBox);
        compositorComboBox->setObjectName("compositorComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(compositorComboBox->sizePolicy().hasHeightForWidth());
        compositorComboBox->setSizePolicy(sizePolicy);
        compositorComboBox->setEditable(true);

        horizontalLayout->addWidget(compositorComboBox);

        findCompositorButton = new QPushButton(groupBox);
        findCompositorButton->setObjectName("findCompositorButton");

        horizontalLayout->addWidget(findCompositorButton);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(WaylandSettings);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_1 = new QHBoxLayout(groupBox_2);
        horizontalLayout_1->setObjectName("horizontalLayout_1");
        wayLockCommandComboBox = new QComboBox(groupBox_2);
        wayLockCommandComboBox->setObjectName("wayLockCommandComboBox");
        sizePolicy.setHeightForWidth(wayLockCommandComboBox->sizePolicy().hasHeightForWidth());
        wayLockCommandComboBox->setSizePolicy(sizePolicy);
        wayLockCommandComboBox->setEditable(true);

        horizontalLayout_1->addWidget(wayLockCommandComboBox);

        findWayLockCommandButton = new QPushButton(groupBox_2);
        findWayLockCommandButton->setObjectName("findWayLockCommandButton");

        horizontalLayout_1->addWidget(findWayLockCommandButton);


        verticalLayout->addWidget(groupBox_2);

        verticalSpacer = new QSpacerItem(10, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(WaylandSettings);

        QMetaObject::connectSlotsByName(WaylandSettings);
    } // setupUi

    void retranslateUi(QWidget *WaylandSettings)
    {
        label->setText(QCoreApplication::translate("WaylandSettings", "Wayland Settings", nullptr));
        groupBox->setTitle(QCoreApplication::translate("WaylandSettings", "Wayland compositor", nullptr));
        findCompositorButton->setText(QCoreApplication::translate("WaylandSettings", "Search...", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("WaylandSettings", "Screenlock command", nullptr));
#if QT_CONFIG(tooltip)
        wayLockCommandComboBox->setToolTip(QCoreApplication::translate("WaylandSettings", "Use \"loginctl lock-session\" on kwin_wayland", nullptr));
#endif // QT_CONFIG(tooltip)
        findWayLockCommandButton->setText(QCoreApplication::translate("WaylandSettings", "Search...", nullptr));
        (void)WaylandSettings;
    } // retranslateUi

};

namespace Ui {
    class WaylandSettings: public Ui_WaylandSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WAYLANDSETTINGS_H
