/********************************************************************************
** Form generated from reading UI file 'x11settings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_X11SETTINGS_H
#define UI_X11SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_X11Settings
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QComboBox *wmComboBox;
    QPushButton *findWmButton;
    QGroupBox *customLockBox;
    QGridLayout *gridLayout_5;
    QComboBox *x11LockCommandComboBox;
    QPushButton *findX11LockCommandButton;
    QGroupBox *scaleBox;
    QFormLayout *formLayout_2;
    QLabel *label_3;
    QDoubleSpinBox *scaleSpinBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *X11Settings)
    {
        if (X11Settings->objectName().isEmpty())
            X11Settings->setObjectName("X11Settings");
        X11Settings->resize(300, 300);
        gridLayout = new QGridLayout(X11Settings);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(X11Settings);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        groupBox = new QGroupBox(X11Settings);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        wmComboBox = new QComboBox(groupBox);
        wmComboBox->setObjectName("wmComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(wmComboBox->sizePolicy().hasHeightForWidth());
        wmComboBox->setSizePolicy(sizePolicy);
        wmComboBox->setEditable(true);

        gridLayout_2->addWidget(wmComboBox, 0, 0, 1, 1);

        findWmButton = new QPushButton(groupBox);
        findWmButton->setObjectName("findWmButton");

        gridLayout_2->addWidget(findWmButton, 0, 1, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);

        customLockBox = new QGroupBox(X11Settings);
        customLockBox->setObjectName("customLockBox");
        customLockBox->setCheckable(true);
        customLockBox->setChecked(false);
        gridLayout_5 = new QGridLayout(customLockBox);
        gridLayout_5->setObjectName("gridLayout_5");
        x11LockCommandComboBox = new QComboBox(customLockBox);
        x11LockCommandComboBox->setObjectName("x11LockCommandComboBox");
        sizePolicy.setHeightForWidth(x11LockCommandComboBox->sizePolicy().hasHeightForWidth());
        x11LockCommandComboBox->setSizePolicy(sizePolicy);
        x11LockCommandComboBox->setEditable(true);

        gridLayout_5->addWidget(x11LockCommandComboBox, 0, 0, 1, 1);

        findX11LockCommandButton = new QPushButton(customLockBox);
        findX11LockCommandButton->setObjectName("findX11LockCommandButton");

        gridLayout_5->addWidget(findX11LockCommandButton, 0, 1, 1, 1);


        gridLayout->addWidget(customLockBox, 2, 0, 1, 2);

        scaleBox = new QGroupBox(X11Settings);
        scaleBox->setObjectName("scaleBox");
        formLayout_2 = new QFormLayout(scaleBox);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::ExpandingFieldsGrow);
        formLayout_2->setHorizontalSpacing(6);
        label_3 = new QLabel(scaleBox);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        scaleSpinBox = new QDoubleSpinBox(scaleBox);
        scaleSpinBox->setObjectName("scaleSpinBox");
        scaleSpinBox->setMinimum(1.000000000000000);
        scaleSpinBox->setMaximum(4.000000000000000);
        scaleSpinBox->setSingleStep(0.500000000000000);
        scaleSpinBox->setValue(1.000000000000000);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, scaleSpinBox);


        gridLayout->addWidget(scaleBox, 3, 0, 1, 2);

        verticalSpacer = new QSpacerItem(10, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacer, 4, 0, 1, 2);


        retranslateUi(X11Settings);

        QMetaObject::connectSlotsByName(X11Settings);
    } // setupUi

    void retranslateUi(QWidget *X11Settings)
    {
        label->setText(QCoreApplication::translate("X11Settings", "X11 Settings", nullptr));
        groupBox->setTitle(QCoreApplication::translate("X11Settings", "Window Manager", nullptr));
        findWmButton->setText(QCoreApplication::translate("X11Settings", "Search...", nullptr));
        customLockBox->setTitle(QCoreApplication::translate("X11Settings", "Use custom screen lock command", nullptr));
        findX11LockCommandButton->setText(QCoreApplication::translate("X11Settings", "Search...", nullptr));
#if QT_CONFIG(tooltip)
        scaleBox->setToolTip(QCoreApplication::translate("X11Settings", "Under Wayland, adjust scaling via compositor settings or kanshi instead.", nullptr));
#endif // QT_CONFIG(tooltip)
        scaleBox->setTitle(QCoreApplication::translate("X11Settings", "Global Screen Scaling", nullptr));
        label_3->setText(QCoreApplication::translate("X11Settings", "Scale factor:", nullptr));
        (void)X11Settings;
    } // retranslateUi

};

namespace Ui {
    class X11Settings: public Ui_X11Settings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_X11SETTINGS_H
