/********************************************************************************
** Form generated from reading UI file 'autostartedit.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOSTARTEDIT_H
#define UI_AUTOSTARTEDIT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_AutoStartEdit
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *nameEdit;
    QLabel *label_3;
    QLineEdit *commandEdit;
    QPushButton *browseButton;
    QCheckBox *trayCheckBox;
    QCheckBox *x11CheckBox;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AutoStartEdit)
    {
        if (AutoStartEdit->objectName().isEmpty())
            AutoStartEdit->setObjectName("AutoStartEdit");
        AutoStartEdit->resize(296, 118);
        gridLayout = new QGridLayout(AutoStartEdit);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(AutoStartEdit);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        nameEdit = new QLineEdit(AutoStartEdit);
        nameEdit->setObjectName("nameEdit");

        gridLayout->addWidget(nameEdit, 0, 1, 1, 2);

        label_3 = new QLabel(AutoStartEdit);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        commandEdit = new QLineEdit(AutoStartEdit);
        commandEdit->setObjectName("commandEdit");

        gridLayout->addWidget(commandEdit, 1, 1, 1, 1);

        browseButton = new QPushButton(AutoStartEdit);
        browseButton->setObjectName("browseButton");

        gridLayout->addWidget(browseButton, 1, 2, 1, 1);

        trayCheckBox = new QCheckBox(AutoStartEdit);
        trayCheckBox->setObjectName("trayCheckBox");

        gridLayout->addWidget(trayCheckBox, 2, 1, 1, 2);

        x11CheckBox = new QCheckBox(AutoStartEdit);
        x11CheckBox->setObjectName("x11CheckBox");

        gridLayout->addWidget(x11CheckBox, 3, 1, 1, 2);

        buttonBox = new QDialogButtonBox(AutoStartEdit);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 4, 0, 1, 3);


        retranslateUi(AutoStartEdit);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AutoStartEdit, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AutoStartEdit, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AutoStartEdit);
    } // setupUi

    void retranslateUi(QDialog *AutoStartEdit)
    {
        AutoStartEdit->setWindowTitle(QCoreApplication::translate("AutoStartEdit", "Edit", nullptr));
        label->setText(QCoreApplication::translate("AutoStartEdit", "Name:", nullptr));
        label_3->setText(QCoreApplication::translate("AutoStartEdit", "Command:", nullptr));
        browseButton->setText(QCoreApplication::translate("AutoStartEdit", "Search...", nullptr));
        trayCheckBox->setText(QCoreApplication::translate("AutoStartEdit", "Wait for system tray", nullptr));
        x11CheckBox->setText(QCoreApplication::translate("AutoStartEdit", "Start only in X11", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AutoStartEdit: public Ui_AutoStartEdit {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUTOSTARTEDIT_H
