/*
 * This file is part of the LXQt project. <https://lxqt.org>
 * Copyright (C) 2015 Luís Pereira <luis.artur.pereira@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef USERLOCATIONSPAGE_H
#define USERLOCATIONSPAGE_H

#include <QWidget>

class UserLocationsPagePrivate;

class UserLocationsPage : public QWidget {
    Q_OBJECT

public:
    explicit UserLocationsPage(QWidget *parent = nullptr);
    ~UserLocationsPage() override;

Q_SIGNALS:
    void needRestart();

public Q_SLOTS:
    void restoreSettings();
    void save();

private Q_SLOTS:
    void clicked(int id);

private:
    UserLocationsPagePrivate *d;
};

#endif // USERLOCATIONSPAGE_H
