/********************************************************************************
** Form generated from reading UI file 'basicsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BASICSETTINGS_H
#define UI_BASICSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_BasicSettings
{
public:
    QGridLayout *gridLayout_3;
    QLabel *label;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QTreeView *moduleView;
    QPushButton *startButton;
    QPushButton *stopButton;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_4;
    QCheckBox *leaveConfirmationCheckBox;
    QCheckBox *lockBeforePowerActionsCheckBox;
    QLabel *powerDelayLabel;
    QSpinBox *powerAfterLockDelaySpinBox;

    void setupUi(QWidget *BasicSettings)
    {
        if (BasicSettings->objectName().isEmpty())
            BasicSettings->setObjectName("BasicSettings");
        BasicSettings->resize(346, 456);
        gridLayout_3 = new QGridLayout(BasicSettings);
        gridLayout_3->setObjectName("gridLayout_3");
        label = new QLabel(BasicSettings);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        gridLayout_3->addWidget(label, 0, 0, 1, 1);

        groupBox_2 = new QGroupBox(BasicSettings);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName("gridLayout");
        moduleView = new QTreeView(groupBox_2);
        moduleView->setObjectName("moduleView");
        moduleView->setAlternatingRowColors(true);
        moduleView->setRootIsDecorated(false);
        moduleView->setHeaderHidden(true);
        moduleView->header()->setStretchLastSection(false);

        gridLayout->addWidget(moduleView, 0, 0, 1, 3);

        startButton = new QPushButton(groupBox_2);
        startButton->setObjectName("startButton");

        gridLayout->addWidget(startButton, 1, 1, 1, 1);

        stopButton = new QPushButton(groupBox_2);
        stopButton->setObjectName("stopButton");

        gridLayout->addWidget(stopButton, 1, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 0, 1, 1);


        gridLayout_3->addWidget(groupBox_2, 1, 0, 1, 1);

        groupBox_3 = new QGroupBox(BasicSettings);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_4 = new QGridLayout(groupBox_3);
        gridLayout_4->setObjectName("gridLayout_4");
        leaveConfirmationCheckBox = new QCheckBox(groupBox_3);
        leaveConfirmationCheckBox->setObjectName("leaveConfirmationCheckBox");

        gridLayout_4->addWidget(leaveConfirmationCheckBox, 0, 0, 1, 2);

        lockBeforePowerActionsCheckBox = new QCheckBox(groupBox_3);
        lockBeforePowerActionsCheckBox->setObjectName("lockBeforePowerActionsCheckBox");

        gridLayout_4->addWidget(lockBeforePowerActionsCheckBox, 1, 0, 1, 2);

        powerDelayLabel = new QLabel(groupBox_3);
        powerDelayLabel->setObjectName("powerDelayLabel");

        gridLayout_4->addWidget(powerDelayLabel, 2, 0, 1, 1);

        powerAfterLockDelaySpinBox = new QSpinBox(groupBox_3);
        powerAfterLockDelaySpinBox->setObjectName("powerAfterLockDelaySpinBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(powerAfterLockDelaySpinBox->sizePolicy().hasHeightForWidth());
        powerAfterLockDelaySpinBox->setSizePolicy(sizePolicy);
        powerAfterLockDelaySpinBox->setMaximum(4500);
        powerAfterLockDelaySpinBox->setSingleStep(250);

        gridLayout_4->addWidget(powerAfterLockDelaySpinBox, 2, 1, 1, 1);


        gridLayout_3->addWidget(groupBox_3, 2, 0, 1, 1);


        retranslateUi(BasicSettings);
        QObject::connect(lockBeforePowerActionsCheckBox, &QCheckBox::toggled, powerAfterLockDelaySpinBox, &QSpinBox::setEnabled);
        QObject::connect(lockBeforePowerActionsCheckBox, &QCheckBox::toggled, powerDelayLabel, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(BasicSettings);
    } // setupUi

    void retranslateUi(QWidget *BasicSettings)
    {
        label->setText(QCoreApplication::translate("BasicSettings", "Basic Settings", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("BasicSettings", "LXQt Modules", nullptr));
        startButton->setText(QCoreApplication::translate("BasicSettings", "Start", nullptr));
        stopButton->setText(QCoreApplication::translate("BasicSettings", "Stop", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("BasicSettings", "Leave Session", nullptr));
        leaveConfirmationCheckBox->setText(QCoreApplication::translate("BasicSettings", "Ask for confirmation to leave session", nullptr));
        lockBeforePowerActionsCheckBox->setText(QCoreApplication::translate("BasicSettings", "Lock screen before suspending/hibernating", nullptr));
        powerDelayLabel->setText(QCoreApplication::translate("BasicSettings", "Suspend/hibernate after lock delay:", nullptr));
        powerAfterLockDelaySpinBox->setSuffix(QCoreApplication::translate("BasicSettings", " ms", nullptr));
        powerAfterLockDelaySpinBox->setPrefix(QString());
        (void)BasicSettings;
    } // retranslateUi

};

namespace Ui {
    class BasicSettings: public Ui_BasicSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BASICSETTINGS_H
