/****************************************************************************
** Meta object code from reading C++ file 'sessiondbusadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lxqt-session-2.4.0/lxqt-session/src/sessiondbusadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessiondbusadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18SessionDBusAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SessionDBusAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18SessionDBusAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SessionDBusAdaptor",
        "D-Bus Interface",
        "org.lxqt.session",
        "moduleStateChanged",
        "",
        "moduleName",
        "state",
        "canLogout",
        "canReboot",
        "canPowerOff",
        "logout",
        "Q_NOREPLY",
        "reboot",
        "powerOff",
        "listModules",
        "QDBusVariant",
        "startModule",
        "name",
        "stopModule",
        "execDesktopFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'moduleStateChanged'
        QtMocHelpers::SignalData<void(QString, bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'canLogout'
        QtMocHelpers::SlotData<bool()>(7, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canReboot'
        QtMocHelpers::SlotData<bool()>(8, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canPowerOff'
        QtMocHelpers::SlotData<bool()>(9, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'logout'
        QtMocHelpers::SlotData<void()>(10, 11, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reboot'
        QtMocHelpers::SlotData<void()>(12, 11, QMC::AccessPublic, QMetaType::Void),
        // Slot 'powerOff'
        QtMocHelpers::SlotData<void()>(13, 11, QMC::AccessPublic, QMetaType::Void),
        // Slot 'listModules'
        QtMocHelpers::SlotData<QDBusVariant()>(14, 4, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'startModule'
        QtMocHelpers::SlotData<void(const QString &)>(16, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'stopModule'
        QtMocHelpers::SlotData<void(const QString &)>(18, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'execDesktopFile'
        QtMocHelpers::SlotData<void(const QString &)>(19, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SessionDBusAdaptor, qt_meta_tag_ZN18SessionDBusAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SessionDBusAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SessionDBusAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SessionDBusAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18SessionDBusAdaptorE_t>.metaTypes,
    nullptr
} };

void SessionDBusAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionDBusAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moduleStateChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: { bool _r = _t->canLogout();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->canReboot();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->canPowerOff();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->logout(); break;
        case 5: _t->reboot(); break;
        case 6: _t->powerOff(); break;
        case 7: { QDBusVariant _r = _t->listModules();
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->startModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->stopModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->execDesktopFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionDBusAdaptor::*)(QString , bool )>(_a, &SessionDBusAdaptor::moduleStateChanged, 0))
            return;
    }
}

const QMetaObject *SessionDBusAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionDBusAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SessionDBusAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SessionDBusAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void SessionDBusAdaptor::moduleStateChanged(QString _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
